# Hentaila

[![PyPI](https://img.shields.io/pypi/v/hentaila)](https://pypi.python.org/pypi/hentaila)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://raw.githubusercontent.com/TaprisSugarbell/Hentaila/main/LICENSE)
- Version: **0.0.2**
- License under: **MIT License**
## Dependencies
- Python == 3.10
- [beautifulsoup4](https://www.crummy.com/software/BeautifulSoup/bs4/doc/)
- [requests](https://requests.readthedocs.io/en/latest/)
## Example of use
### recent hentai's
```python
from hentaila.hentaila import Hentaila
h = Hentaila()
print(h.recents())
```
